# arpes.endstations.plugin.ALG\_main module

**class arpes.endstations.plugin.ALG\_main.ALGMainChamber**

> Bases:
> [arpes.endstations.HemisphericalEndstation](arpes.endstations#arpes.endstations.HemisphericalEndstation),
> [arpes.endstations.FITSEndstation](arpes.endstations#arpes.endstations.FITSEndstation)
> 
> `ALIASES = ['MC', 'ALG-Main', 'ALG-MC', 'ALG-Hemisphere', 'ALG-Main
> Chamber']`
> 
> `ATTR_TRANSFORMS = {'START_T': <function ALGMainChamber.<lambda>>}`
> 
> `MERGE_ATTRS = {'analyzer': 'Specs ... robe_linewidth': 0.015}`
> 
> `PRINCIPAL_NAME = 'ALG-Main'`
> 
> `RENAME_KEYS = {'Alpha': 'alpha', ' ... _func': 'workfunction'}`
> 
> **postprocess\_final(data: xarray.core.dataset.Dataset, scan\_desc:
> dict = None)**
